@@ -118,7 +118,7 @@ gdata_documents_text_new (const gchar *id)
  * If @destination_file is a directory, then the file will be downloaded in this directory with the #GDataEntry:title with 
  * the apropriate extension as name.
  *
- * If there is an error getting the document, a %GDATA_SERVICE_ERROR_WITH_QUERY error will be returned.
+ * If there is an error getting the document, a %GDATA_SERVICE_ERROR_PROTOCOL_ERROR error will be returned.
  *
  * Return value: the document's data, or %NULL; unref with g_object_unref()
  *
@@ -170,5 +170,6 @@ gdata_documents_text_get_download_uri (GDataDocumentsText *self, GDataDocumentsT
 	document_id = gdata_documents_entry_get_document_id (GDATA_DOCUMENTS_ENTRY (self));
 	g_assert (document_id != NULL);
 
-	return g_strdup_printf ("http://docs.google.com/feeds/download/documents/Export?exportFormat=%s&docID=%s", export_formats[export_format], document_id);
+	return g_strdup_printf ("%s://docs.google.com/feeds/download/documents/Export?exportFormat=%s&docID=%s",
+	                        _gdata_service_get_scheme (), export_formats[export_format], document_id);
 }
